from gardnr import drivers, logger, metrics


class Sensor(drivers.Sensor):
    """
    Add code to interface with physical or virtual sensors here.
    """

    def setup(self):
        """
        Add configuration here
        """

        # remove the next line and add code
        pass

    def read(self):
        """
        Example log:

        metrics.create_metric_log('my-metric', 42)


        Example image log:

        metrics.create_image_log(
            self.metric_name,
            image_bytes,
            extension=self.image_file_extension
        )
        """

        # remove the next line and add code
        pass
